@@ -33,7 +33,7 @@ my %no_notify =
    map { $_ => 1 }
        qw(program line subroutine package filename codeline
           filenames break_points codelines pad finished
-          break_points_file);
+          is_running);
 
 our $AUTOLOAD;
 sub AUTOLOAD {
@@ -52,6 +52,12 @@ sub AUTOLOAD {
     }
 }
 
+sub is_running {
+    my( $self ) = @_;
+
+    return $self->argv && !$self->ebug->finished;
+}
+
 sub load_program {
     my( $self, $argv ) = @_;
     $self->{argv} = $argv || $self->{argv} || [];
