@@ -2,6 +2,8 @@ package Devel::ebug::Wx::View::Code::STC;
 
 use Wx::STC;
 
+# FIXME split in a fully-fledged view linked to the code display service
+#       and a simple code-edit/display control
 use strict;
 use base qw(Wx::StyledTextCtrl Devel::ebug::Wx::View::Base);
 
@@ -15,6 +17,8 @@ use constant { CURRENT_LINE => 2,
                BACKGROUND   => 3,
                };
 
+sub tag { 'code_stc' }
+
 sub new {
     my( $class, $parent, $wxebug ) = @_;
     my $self = $class->SUPER::new( $parent, -1 );
@@ -110,6 +114,7 @@ sub highlight_line {
     $self->highlighted_line( $line );
 }
 
+# FIXME make it configurable with a default
 sub _setup_stc {
     my( $self ) = @_;
     my $font = Wx::Font->new( 10, wxTELETYPE, wxNORMAL, wxNORMAL );
@@ -118,52 +123,26 @@ sub _setup_stc {
     $self->StyleSetFont( wxSTC_STYLE_DEFAULT, $font );
     $self->StyleClearAll();
 
-    $self->StyleSetForeground(0, Wx::Colour->new(0x00, 0x00, 0x7f));
-    $self->StyleSetForeground(1,  Wx::Colour->new(0xff, 0x00, 0x00));
-
-    # 2 Comment line green
-    $self->StyleSetForeground(2,  Wx::Colour->new(0x00, 0x7f, 0x00));
-    $self->StyleSetForeground(3,  Wx::Colour->new(0x7f, 0x7f, 0x7f));
-
-    # 4 numbers
-    $self->StyleSetForeground(4,  Wx::Colour->new(0x00, 0x7f, 0x7f));
-    $self->StyleSetForeground(5,  Wx::Colour->new(0x00, 0x00, 0x7f));
-
-    # 6 string orange
-    $self->StyleSetForeground(6,  Wx::Colour->new(0xff, 0x7f, 0x00));
-
-    $self->StyleSetForeground(7,  Wx::Colour->new(0x7f, 0x00, 0x7f));
-
-    $self->StyleSetForeground(8,  Wx::Colour->new(0x00, 0x00, 0x00));
-
-    $self->StyleSetForeground(9,  Wx::Colour->new(0x7f, 0x7f, 0x7f));
-
-    # 10 operators dark blue
-    $self->StyleSetForeground(10, Wx::Colour->new(0x00, 0x00, 0x7f));
-
-    # 11 identifiers bright blue
-    $self->StyleSetForeground(11, Wx::Colour->new(0x00, 0x00, 0xff));
-
-    # 12 scalars purple
-    $self->StyleSetForeground(12, Wx::Colour->new(0x7f, 0x00, 0x7f));
-
-    # 13 array light blue
-    $self->StyleSetForeground(13, Wx::Colour->new(0x40, 0x80, 0xff));
-
-    # 17 matching regex red
-    $self->StyleSetForeground(17, Wx::Colour->new(0xff, 0x00, 0x7f));
-
-    # 18 substitution regex light olive
-    $self->StyleSetForeground(18, Wx::Colour->new(0x7f, 0x7f, 0x00));
-
-    #Set a style 12 bold
-    $self->StyleSetBold(12,  1);
-
-    # Apply tag style for selected lexer (blue)
-    $self->StyleSetSpec( wxSTC_H_TAG, "fore:#0000ff" );
+    $self->StyleSetSpec( wxSTC_PL_DEFAULT, 'fore:#00007f' );
+    $self->StyleSetSpec( wxSTC_PL_ERROR, 'fore:#ff0000' );
+    $self->StyleSetSpec( wxSTC_PL_COMMENTLINE, 'fore:#007f00' );
+    $self->StyleSetSpec( wxSTC_PL_POD, 'fore:#7f7f7f' );
+    $self->StyleSetSpec( wxSTC_PL_NUMBER, 'fore:#007f7f' );
+    $self->StyleSetSpec( wxSTC_PL_WORD, 'fore:#00007f' );
+    $self->StyleSetSpec( wxSTC_PL_STRING, 'fore:#ff7f00' );
+    $self->StyleSetSpec( wxSTC_PL_CHARACTER, 'fore:#7f007f' );
+    $self->StyleSetSpec( wxSTC_PL_PUNCTUATION, 'fore:#000000' );
+    $self->StyleSetSpec( wxSTC_PL_PREPROCESSOR, 'fore:#7f7f7f' );
+    $self->StyleSetSpec( wxSTC_PL_OPERATOR, 'fore:#00007f' );
+    $self->StyleSetSpec( wxSTC_PL_IDENTIFIER, 'fore:#00007f' );
+    $self->StyleSetSpec( wxSTC_PL_SCALAR, 'fore:#7f007f,bold' );
+    $self->StyleSetSpec( wxSTC_PL_ARRAY, 'fore:#4080ff,bold' );
+    $self->StyleSetSpec( wxSTC_PL_REGEX, 'fore:#ff007f' );
+    $self->StyleSetSpec( wxSTC_PL_REGSUBST, 'fore:#7f7f00' );
 
     $self->SetLexer( wxSTC_LEX_PERL );
 
+    # FIXME colors and markers configurable?
     $self->MarkerDefine( CURRENT_LINE, 2,  Wx::wxGREEN, Wx::wxNullColour );
     $self->MarkerDefine( BREAKPOINT  , 0,  Wx::wxBLUE, Wx::wxNullColour );
     $self->MarkerDefine( BACKGROUND  , 22, Wx::wxNullColour, Wx::Colour->new( 0x90, 0x90, 0x90 ) );
@@ -171,6 +150,7 @@ sub _setup_stc {
     $self->SetReadOnly( 1 );
     $self->SetMarginSensitive( 1, 1 );
 
+    # FIXME: move to code display service
     EVT_STC_MARGINCLICK( $self, $self, sub { $self->_set_bp( $_[1] ) } );
     EVT_CHAR( $self, sub {
                   $self->wxebug->command_manager_service->handle_key( $_[1]->GetKeyCode );
@@ -202,4 +182,3 @@ sub _set_bp {
 }
 
 1;
-
